@@ -10,8 +10,17 @@ import pandas as pd
 from nltk.tokenize import word_tokenize
 from nltk.tokenize import ToktokTokenizer
 from collections import Counter
+from snlp import logger 
+
+
+"""
+TODO: 
+    
+    1. Include more AMs
+    2. Include SDMA
+    3. Function to create embedding for MWEs by combining the embeding of their components. 
+"""
 
-nltk.download('averaged_perceptron_tagger')
 
 def extract_ncs_from_sent(sentence):
     """Extract two-word noun compounds from tokenized input. 
@@ -24,6 +33,12 @@ def extract_ncs_from_sent(sentence):
         JNs_counts (dict): Dictionary of adjective-noun compounds to their count in sentence. 
         word_counts (dict) Dictionary of words to their count in sentence. 
     """
+    if not isinstance(sentence, str):
+        raise TypeError('Input must be a string.')
+    
+    if len(sentence) == 0:
+        return
+        
     tokens = sentence.split(" ")
     postag_tokens = nltk.pos_tag(tokens)
     JNs = []
